@@ -24,10 +24,12 @@ pub fn external(
         f32::datum_type()
     } else if type_name == TypeName::Logical {
         bool::datum_type()
+    } else if type_name == TypeName::Integer {
+        i64::datum_type()
     } else {
         todo!()
     };
-    let shape: TVec<usize> = invocation.named_arg_as(builder, "shape")?;
+    let shape: TVec<TDim> = invocation.named_arg_as(builder, "shape")?;
     Ok(tvec!(builder.model.add_source("", TypedFact::dt_shape(dt, &shape))?))
 }
 
@@ -564,14 +566,70 @@ pub fn select(
 }
 
 /*
- * fragment prelu( x: tensor<scalar>, alpha: tensor<scalar> )-> ( y: tensor<scalar> )
+ * fragment leaky_relu( x: tensor<scalar>, alpha: scalar )-> ( y: tensor<scalar> )
  */
 
-pub fn prelu(
+pub fn leaky_relu(
     builder: &mut ModelBuilder,
     invocation: &ResolvedInvocation,
 ) -> TractResult<TVec<OutletId>> {
     let x = invocation.named_arg_as(builder, "x")?;
     let alpha = invocation.named_arg_as(builder, "alpha")?;
-    builder.wire(ops::nn::prelu(alpha) , &[x])
+    builder.wire(ops::nn::leaky_relu(alpha), &[x])
+}
+
+/*
+ * fragment stack<?>( values: tensor<?>[], axis: integer ) -> ( value: tensor<?> )
+ *
+ * Same as concat but on dedicated axis
+ */
+
+pub fn stack(
+    builder: &mut ModelBuilder,
+    invocation: &ResolvedInvocation,
+) -> TractResult<TVec<OutletId>> {
+    let axis: usize = invocation.named_arg_as(builder, "axis")?;
+    let mut values: TVec<OutletId> = invocation.named_arg_as(builder, "values")?;
+    if let Some(Some(dt)) = invocation.dt_from_quant_file.get(0) {
+        for value in &mut values {
+            if builder.model.node(value.node).outputs[value.slot].fact.datum_type != *dt {
+                *value = builder.wire(ops::cast::cast(*dt), &[*value])?[0];
+            }
+        }
+    }
+
+    for value in &mut values {
+        // add unsqueeze
+        *value = builder.wire(ops::change_axes::AxisOp::Add(axis as usize), &[*value])?[0];
+    }
+
+    builder.wire(ops::array::TypedConcat::concat_vars(axis, values.len()), &values)
+}
+
+/*
+ * fragment unstack<?>( value: tensor<?>, axis: integer ) -> ( values: tensor<?>[] )
+ *
+ * Inverse of stack operator
+ */
+pub fn unstack(
+    builder: &mut ModelBuilder,
+    invocation: &ResolvedInvocation,
+) -> TractResult<TVec<OutletId>> {
+    let wire = tvec!(invocation.named_arg_as(builder, "value")?);
+    let axis: usize = invocation.named_arg_as(builder, "axis")?;
+
+    let input_fact = builder.model.outlet_fact(wire[0])?.clone();
+
+    (0..input_fact.shape[axis].clone().to_i32()?)
+        .into_iter()
+        .map(|start_int| {
+            let start = start_int.to_dim();
+            let end = (start_int + 1).to_dim();
+            let sliced_wire =
+                builder.wire(tract_core::ops::array::Slice { axis, start, end }, &wire)?;
+            let squeezed_wire =
+                builder.wire(ops::change_axes::AxisOp::Rm(axis as usize), &sliced_wire)?;
+            Ok(squeezed_wire[0])
+        })
+        .collect()
 }
