@@ -44,6 +44,9 @@ pub fn tract_nnef() -> Registry {
     primitive(&mut registry, "pad", deser::pad);
     dumper!(ops::array::Pad, ser::pad);
 
+    primitive(&mut registry, "stack", deser::stack);
+    primitive(&mut registry, "unstack", deser::unstack);
+
     registry.register_binary("add", &ops::math::Add {});
     registry.register_binary("sub", &ops::math::Sub {});
     registry.register_binary("mul", &ops::math::Mul {});
@@ -85,11 +88,11 @@ pub fn tract_nnef() -> Registry {
     registry.register_unit_element_wise("neg", &ops::math::Neg {});
 
     registry.register_element_wise(
-        "prelu",
-        TypeId::of::<ops::nn::Prelu>(),
-        ser::prelu,
-        vec![TypeName::Scalar.tensor().named("x"), TypeName::Scalar.tensor().named("alpha")],
-        deser::prelu,
+        "leaky_relu",
+        TypeId::of::<ops::nn::LeakyRelu>(),
+        ser::leaky_relu,
+        vec![TypeName::Scalar.tensor().named("x"), TypeName::Scalar.named("alpha")],
+        deser::leaky_relu,
     );
 
     registry.register_binary("lt", &ops::logic::Less {});
