@@ -1,3 +1,5 @@
+use std::ops::ControlFlow;
+
 use crate::internal::*;
 
 use crate::ast;
@@ -11,24 +13,29 @@ pub type FromTract = fn(&mut IntoAst, node: &TypedNode) -> TractResult<Option<Ar
 
 pub struct Registry {
     pub id: String,
+    pub aliases: Vec<String>,
     pub fragments: HashMap<String, FragmentDef>,
     pub primitives: HashMap<String, (Vec<ast::Parameter>, ToTract)>,
     pub unit_element_wise_ops: Vec<(String, Box<dyn ElementWiseMiniOp>)>,
     pub element_wise_ops: Vec<(String, TypeId, FromTract, Vec<ast::Parameter>, ToTract)>,
     pub binary_ops: Vec<(String, Box<dyn BinMiniOp>, Option<Box<dyn BinMiniOp>>)>,
     pub from_tract: HashMap<TypeId, FromTract>,
+    pub extensions:
+        Vec<Box<dyn Fn(&mut crate::deser::ModelBuilder, &[String]) -> TractResult<ControlFlow<(), ()>>>>,
 }
 
 impl Registry {
     pub fn new(id: impl Into<String>) -> Registry {
         Registry {
             id: id.into(),
+            aliases: Default::default(),
             primitives: Default::default(),
             fragments: Default::default(),
             from_tract: Default::default(),
             unit_element_wise_ops: Default::default(),
             element_wise_ops: Default::default(),
             binary_ops: Default::default(),
+            extensions: Default::default(),
         }
     }
 
@@ -171,7 +178,8 @@ impl Registry {
             return Ok(Some(Value::Wire(outlet[0])));
         }
         if let Some(ew) = self.element_wise_ops.iter().find(|ew| ew.0 == invocation.id) {
-            let resolved = ResolvedInvocation { invocation, default_params: &ew.3, dt_from_quant_file: dt };
+            let resolved =
+                ResolvedInvocation { invocation, default_params: &ew.3, dt_from_quant_file: dt };
             return Ok(Some(Value::Wire(
                 (ew.4)(builder, &resolved)
                     .with_context(|| format!("Deserializing op `{}'", invocation.id))?[0],
